# trashf
CLI tool to safely remove any file and directory by putting them in the trash  

Move any file or directory in the trash in a clever and safe way when wanting to remove them. If a file or folder with the same name already exist in the trash, the file or folder to be removed will be renamed with the date before to be moved to the trash (fname + "%Y_%m_%d-%H_%M_%S").


# Installation
```sh
With pip:
sudo pip3 install trashf

With yay:
yay -a trashf

With yaourt:
yaourt -a trashf
```

# Compatibility
python >= 3


# Usage
<pre>
<b>trashf / rt</b> [<b>F_PATH_01 F_PATH_02 ...</b>]
<b>options:</b>
<!-- -->         <b>-h, --help</b>        show this help message and exit
</pre>


# Examples
For **help**:<br/>
```sh
trashf -h
or
rt --help
```

**Move** in the trash ($HOME/.local/share/Trash/files) files and folders:<br/>
```sh
trashf titi/ toto.jpg
```
